/*
 * CatGraphicsPanel.java
 *
 * Copyright (c) 2013 Jessica Hu. All Rights Reserved.
 *
 * history:
 *      jhu 08april2013: began program
 *
 */

import javax.swing.*;
import java.awt.*;
import java.awt.event.*;

/**
 * 
 * @version 1.0 08 April 2013
 * @author Jessica Hu
 *
 * The graphics panel that updates the animation.
 *
 */
public class CatGraphicsPanel extends JPanel
{
   //constants for width/height, max force, etc.
   private final int PANEL_WIDTH = 500;
   private final int PANEL_HEIGHT = 500;
   private final int MAXIMUM_FORCE = 20;
   
   //timers and stuff for updating panel
   private int m_interval = 25;  //ms between updates
   private Timer timer;        //animate a step
   
   //representing the cats - 5 onscreen at all times
   private Cat cat, cat1, cat2, cat3, cat4, cat5, cat6, cat7, cat8, cat9;
   
   //make an image to make as the background
   Image img = Toolkit.getDefaultToolkit().createImage("cat_background_500.png");
   
   /**
    *  Sets up this panel with the background, size, and initial force.
    */
   public CatGraphicsPanel(int inputForce)
   {
       setPreferredSize (new Dimension(PANEL_WIDTH, PANEL_HEIGHT));
       
       timer = new Timer(m_interval, new TimerAction());
       
       //instantiate 5 cats
       cat = new Cat (inputForce);
       cat1 = new Cat (inputForce);
       cat2 = new Cat (inputForce);
       cat3 = new Cat (inputForce);
       cat4 = new Cat (inputForce);
       cat5 = new Cat (inputForce);
       cat6 = new Cat (inputForce);
       
       timer.start();
   }
   
   /**
    * Updates the graphics panel
    */
   public void paintComponent(Graphics g)
   {
       super.paintComponent(g);
       g.drawImage(img, 0, 0, null);
       cat.draw(g);
       cat1.draw(g);
       cat2.draw(g);
       cat3.draw(g);
       cat4.draw(g);
       cat5.draw(g);
       cat6.draw(g);
    }
    
   /**
    * Returns the total current (changable) force to the actionlisteners on the applet
    */
   public int getTotalForce()
   {
       return cat.getCurrentForce();
    }
    
   /**
    * Returns the maximum (unchangable) force to the actionlisteners on the applet
    */
   public int getMaxForce()
   {
       return MAXIMUM_FORCE;
    }
   
   /**
    * Sets the force in the Cat class after getting it from the CatApplet
    */
   public void setTotalForce(int inputTotalForce)
   {
      cat.setCurrentForce(inputTotalForce);
      cat1.setCurrentForce(inputTotalForce);
      cat2.setCurrentForce(inputTotalForce);
      cat3.setCurrentForce(inputTotalForce);
      cat4.setCurrentForce(inputTotalForce);
      cat5.setCurrentForce(inputTotalForce);
      cat6.setCurrentForce(inputTotalForce);
    }

   class TimerAction implements ActionListener {
       /** 
        * Will update the cat's position every time it's called (every 20 ms)
        */
       public void actionPerformed(ActionEvent e) {
           cat.setBounds(getWidth(), getHeight());
           cat.move();  // Move the cat.
           cat1.setBounds(getWidth(), getHeight());
           cat1.move();
           cat2.setBounds(getWidth(), getHeight());
           cat2.move();
           cat3.setBounds(getWidth(), getHeight());
           cat3.move();
           cat4.setBounds(getWidth(), getHeight());
           cat4.move();
           cat5.setBounds(getWidth(), getHeight());
           cat5.move();
           cat6.setBounds(getWidth(), getHeight());
           cat6.move();
           
           repaint();
       }
   }
}